# LOC LM

LOC LM (Lightweight Optimzed Context Language Model) is a graph base languege model which is very lightweight and trained on specific domain data. 

Currently it only has trained model for cell mechanics but more are under development 

For usage have look at this [notebook](https://github.com/utksara/loclm/blob/master/demo.ipynb)